@@ -1,9 +1,10 @@
 import base64
+import itertools
 import logging
 import os
 import warnings
 from binascii import Error as BinAsciiError
-from typing import Optional, Union
+from typing import Dict, Generator, Optional, Union, overload
 
 from aws_lambda_powertools.shared import constants
 
@@ -47,6 +48,21 @@ def resolve_truthy_env_var_choice(env: str, choice: Optional[bool] = None) -> bo
     return choice if choice is not None else strtobool(env)
 
 
+@overload
+def resolve_env_var_choice(env: Optional[str], choice: float) -> float:
+    ...
+
+
+@overload
+def resolve_env_var_choice(env: Optional[str], choice: str) -> str:
+    ...
+
+
+@overload
+def resolve_env_var_choice(env: Optional[str], choice: Optional[str]) -> str:
+    ...
+
+
 def resolve_env_var_choice(
     env: Optional[str] = None, choice: Optional[Union[str, float]] = None
 ) -> Optional[Union[str, float]]:
@@ -100,3 +116,8 @@ def powertools_debug_is_set() -> bool:
         return True
 
     return False
+
+
+def slice_dictionary(data: Dict, chunk_size: int) -> Generator[Dict, None, None]:
+    for _ in range(0, len(data), chunk_size):
+        yield {dict_key: data[dict_key] for dict_key in itertools.islice(data, chunk_size)}
