@@ -1,4 +1,4 @@
-from typing import Iterator, List
+from typing import Iterator, List, Optional
 
 from aws_lambda_powertools.utilities.data_classes.common import DictWrapper
 
@@ -26,7 +26,7 @@ class SESMailCommonHeaders(DictWrapper):
         return self["from"]
 
     @property
-    def date(self) -> List[str]:
+    def date(self) -> str:
         """The date and time when Amazon SES received the message."""
         return self["date"]
 
@@ -45,6 +45,26 @@ class SESMailCommonHeaders(DictWrapper):
         """The value of the Subject header for the email."""
         return str(self["subject"])
 
+    @property
+    def cc(self) -> Optional[List[str]]:
+        """The values in the CC header of the email."""
+        return self.get("cc")
+
+    @property
+    def bcc(self) -> Optional[List[str]]:
+        """The values in the BCC header of the email."""
+        return self.get("bcc")
+
+    @property
+    def sender(self) -> Optional[List[str]]:
+        """The values in the Sender header of the email."""
+        return self.get("sender")
+
+    @property
+    def reply_to(self) -> Optional[List[str]]:
+        """The values in the replyTo header of the email."""
+        return self.get("replyTo")
+
 
 class SESMail(DictWrapper):
     @property
@@ -94,6 +114,9 @@ class SESMail(DictWrapper):
 class SESReceiptStatus(DictWrapper):
     @property
     def status(self) -> str:
+        """Receipt status
+        Possible values: 'PASS', 'FAIL', 'GRAY', 'PROCESSING_FAILED', 'DISABLED'
+        """
         return str(self["status"])
 
 
@@ -107,6 +130,12 @@ class SESReceiptAction(DictWrapper):
         # Note: this name conflicts with existing python builtins
         return self["type"]
 
+    @property
+    def topic_arn(self) -> Optional[str]:
+        """String that contains the Amazon Resource Name (ARN) of the Amazon SNS topic to which the
+        notification was published."""
+        return self.get("topicArn")
+
     @property
     def function_arn(self) -> str:
         """String that contains the ARN of the Lambda function that was triggered.
@@ -154,12 +183,24 @@ class SESReceipt(DictWrapper):
         """Object that indicates whether the Sender Policy Framework (SPF) check passed."""
         return SESReceiptStatus(self["spfVerdict"])
 
+    @property
+    def dkim_verdict(self) -> SESReceiptStatus:
+        """Object that indicates whether the DomainKeys Identified Mail (DKIM) check passed"""
+        return SESReceiptStatus(self["dkimVerdict"])
+
     @property
     def dmarc_verdict(self) -> SESReceiptStatus:
         """Object that indicates whether the Domain-based Message Authentication,
         Reporting & Conformance (DMARC) check passed."""
         return SESReceiptStatus(self["dmarcVerdict"])
 
+    @property
+    def dmarc_policy(self) -> Optional[str]:
+        """Indicates the Domain-based Message Authentication, Reporting & Conformance (DMARC) settings for
+        the sending domain. This field only appears if the message fails DMARC authentication.
+        Possible values for this field are: none, quarantine, reject"""
+        return self.get("dmarcPolicy")
+
     @property
     def action(self) -> SESReceiptAction:
         """Object that encapsulates information about the action that was executed."""
